function varargout = verop(varargin)
% VEROP M-file for verop.fig
%      VEROP, by itself, creates a new VEROP or raises the existing
%      singleton*.
%
%      H = VEROP returns the handle to a new VEROP or the handle to
%      the existing singleton*.
%
%      VEROP('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in VEROP.M with the given input arguments.
%
%      VEROP('Property','Value',...) creates a new VEROP or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before verop_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to verop_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help verop

% Last Modified by GUIDE v2.5 04-Jul-2010 23:07:04

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @verop_OpeningFcn, ...
                   'gui_OutputFcn',  @verop_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before verop is made visible.
function verop_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to verop (see VARARGIN)

% Choose default command line output for verop
handles.output = hObject;

O=varargin{1};

cadena=O{1};
if length(cadena{1})>58
    set(handles.textarchivo1,'FontSize',8)
end
set(handles.textarchivo1,'String',cadena);

cadena=O{2};
if length(cadena{1})>58
    set(handles.textmodelo1,'FontSize',9)
end
set(handles.textmodelo1,'String',cadena);

cadena=O{3};
if length(cadena{1})>58
    set(handles.textnombreop1,'FontSize',9)
end
set(handles.textnombreop1,'String',cadena);

serie=O{4};
set(handles.textserie1,'String',serie);

cadena=O{5};
if length(cadena{1})>58
    set(handles.textpiloto1,'FontSize',9)
end
set(handles.textpiloto1,'String',cadena);

hora=O{6};
minuto=O{7};
lahora=[num2str(hora),':',num2str(minuto)];
set(handles.texthora1,'String',lahora);

dia=O{8};
mes=O{9};
anyo=O{10};
lafecha=[num2str(dia),'/',num2str(mes),'/',num2str(anyo)];
set(handles.textfecha1,'String',lafecha);

comienzo=O{11};
set(handles.textcomienzo1,'String',num2str(comienzo));

final=O{12};
set(handles.textfinal1,'String',num2str(final));

cadena=O{13};
if length(cadena{1})>58
    set(handles.textdicc1,'FontSize',9)
end
set(handles.textdicc1,'String',cadena);

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes verop wait for user response (see UIRESUME)
uiwait(handles.figureverop);


% --- Outputs from this function are returned to the command line.
function varargout = verop_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
delete(handles.figureverop);


% --- Executes on button press in pushbuttonaceptar.
function pushbuttonaceptar_Callback(hObject, eventdata, handles)
% hObject    handle to pushbuttonaceptar (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

uiresume(handles.figureverop);


% --- Executes when user attempts to close figureverop.
function figureverop_CloseRequestFcn(hObject, eventdata, handles)
% hObject    handle to figureverop (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: delete(hObject) closes the figure
uiresume(handles.figureverop);
